#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Crée le Mon Feb 14 10:34:29 2022
@auteur: david ALBERTO      (www.astrolabe-science.fr)
Ce code utilise le module mendeleev (données sur les éléments chimiques)
Dans ce module, un élément est appelé par element(N) pour récupérer
les données suiantes :
    - symbole
    - period : c'est le numéro de ligne
"""
# Appel des modules
import matplotlib.pyplot as plt
import matplotlib as mpl#Normalisation des valeurs
import pandas as pd
import numpy as np# gestion des données numériques absentes (NaN)
from mendeleev import element

 # Paramètres personnalisables-----

"""
Les paramètres suivants sont liés entre eux, pour le rendu final.
Ils doivent être ajustés manuellement :
    - dimensions de la figure
    - valeurs des paramètres d'échelle a et b
    - taille des caractères
    - les différents offsets en x et en y
"""
couleur_fond = 'lightcyan'
Zmax = 118

# sélection des numéros atomiques à afficher :
# liste_Z = np.concatenate((
#     np.arange(1,56+1),
#     np.arange(71,86)
#     ))
liste_Z = np.arange(1,Zmax+1) # pour tous les éléments

plt.rcParams["font.family"] = "Roboto" # ou autre police installée
# ---------------------------------

def existe(fichier):
    """
    Renvoie True si le fichier existe dans le répertoire du script, False sinon.
    """
    try:
        f = open(fichier,'r')
        f.close()
        return True
    except:
        return False

Z_haut = [1, 6, 8, 10, 12, 16, 18, 20, 26, 28, 32, 40,50,54,56,78,82]
Z_bas = [3, 4, 5, 9, 21, 23, 25,27,29,31,33,45,49, 73]

def etiquettes():
    """
    affiche les symboles des éléments listés dans les listes Z_haut et Z_bas.
    """
    for Z in Z_haut:
        y = tableau.loc[tableau.Z == Z, 'abondance']
        texte = tableau.loc[tableau.Z == Z, 'symbole'].values[0]
        ax.text(Z, y + 0.2, texte, ha='center')
    for Z in Z_bas:
        y = tableau.loc[tableau.Z == Z, 'abondance']
        texte = tableau.loc[tableau.Z == Z, 'symbole'].values[0]
        ax.text(Z, y - 0.2, texte, ha='center', va='center')

# ---------------------------------

# import des données d'abondance dans le système solaire, d'après fichier externe :
abondanceSS = pd.read_csv('abondance_systeme_sol.csv', skiprows=1, sep='\t')


if existe('tableau.csv'):
    tableau = pd.read_csv("tableau.csv", sep='\t')
else:# creation des listes de lignes et colonnes, ainsi que du fichier csv les contenant.
    symbole=[]
    for Z in liste_Z:
        Z = int(Z)
        symb = element(Z).symbol
        symbole.append(symb)

    #enregistrement pour usage ultérieur, afin de gagner du temps
    tableau = pd.DataFrame(
                    {'Z' : liste_Z,
                     'symbole' : symbole,
                     'abondance': np.nan
                        }
        )

    # itération sur abondanceSS pour chercher les abondances et les placer dans 'tableau
    for Z in abondanceSS['Z'].values:
        abo = abondanceSS.loc[abondanceSS['Z'] == Z, 'abondance'].values[0]
        abo = np.log10(abo)
        tableau.loc[tableau['Z'] == Z, 'abondance'] = abo

    tableau.to_csv('tableau.csv',index=False, sep='\t', na_rep='nan')

abondance_log = tableau['abondance']
# ---------------------------------

# paramètres du graphique
fig=plt.figure(figsize=(29.7/2.54,21/2.54),tight_layout=True,facecolor=couleur_fond)

ax=plt.subplot(111)

plt.title("Abondance des éléments chimiques dans le Système solaire",fontsize=20,y=0.90)
ax.set_xlabel('numéro atomique Z')
ax.set_ylabel('abondance (échelle log)')
# plt.xticks([])
# plt.yticks([])
# ---------------------------------

etiquettes()

x = tableau['Z']
y = tableau['abondance']

# tracé de la courbe :
ax.plot(x,y, c='royalblue')
ax.scatter(x,y, s=20, marker='o',c='orangered',zorder=2)

# signature :
plt.text(0.985,0.02,'D. Alberto (www.astrolabe-science.fr) Données : La radioactivité, Y. Chelet, Nucleon 2006.',
          rotation=90,fontsize=6,transform=ax.transAxes)

NomFichier="GrapheAbondanceSystSol"
fig.savefig(NomFichier+'.png',dpi=200)
fig.savefig(NomFichier+'.pdf')
